@@ -1,24 +1,9 @@
 package Log::ger::Output;
 
-our $DATE = '2017-06-21'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2017-06-23'; # DATE
+our $VERSION = '0.005'; # VERSION
 
-use strict;
-use warnings;
-
-sub set {
-    my $pkg = shift;
-
-    require Log::ger::Util;
-    Log::ger::Util::set_output(@_);
-}
-
-sub import {
-    my $pkg = shift;
-    if (@_) {
-        set($pkg, @_);
-    }
-}
+use parent 'Log::ger::Plugin';
 
 1;
 # ABSTRACT: Set logging output
@@ -35,16 +20,29 @@ Log::ger::Output - Set logging output
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
+To set globally:
+
  use Log::ger::Output;
- Log::ger::Output->set('Screen', use_color=>1, ...);
+ Log::ger::Output->set(Screen => (
+     use_color => 1,
+     ...
+ );
 
 or:
 
- use Log::ger::Output Screen => (
+ use Log::ger::Output 'Screen', (
+     use_color=>1,
+ ...
+ );
+
+To set for current package only:
+
+ use Log::ger::Output;
+ Log::ger::Output->set_for_current_package(Screen => (
      use_color => 1,
      ...
  );
@@ -53,7 +51,11 @@ or:
 
 =head1 SEE ALSO
 
-Modelled after L<Log::Any::Adapter>.
+L<Log::ger::Format>
+
+L<Log::ger::Filter>
+
+L<Log::ger::Plugin>
 
 =head1 AUTHOR
 
